@@ -1,6 +1,7 @@
 import click
 import git
 from gitutor.init.commands import init
+from gitutor.save.commands import save
 
 
 @click.group()
@@ -14,13 +15,15 @@ def cli(ctx):
         try:
             repo = git.Repo(".", search_parent_directories=True)
             ctx.obj['REPO'] = repo
-            print( f"Location {repo.working_tree_dir}" )
-            print(f"Remote from init: {repo.remote('origin').url} ")
-        except:
-            print("not git repo")
+            #print( f"Location {repo.working_tree_dir}" )
+            #print(f"Remote from init: {repo.remote('origin').url} ")
+        except Exception as e: 
+            click.echo(e)
+            #print("not git repo")
             exit()
 
 cli.add_command(init)
+cli.add_command(save)
 
 def main():
     cli(obj={})
